References
----------

The ``TaylorF2`` template in this module restricts to the (l=2,m=2) harmonic. 

The expressions for the amplitude and phase of the waveform are extracted from the following papers [*]_

Point particle terms up to 3.5PN in the phase
  Eq.s (B6-13) in `1508.07253 <https://arxiv.org/abs/1508.07253>`_
Spin-induced terms up to 3.5PN in the phase [*]_
  Eq.s (0.5a-c) in `1701.06318 <https://arxiv.org/abs/1701.06318>`_
Terms up to 3.5PN in the amplitude
  Eq.s (B14-20) in  `1508.07253 <https://arxiv.org/abs/1508.07253>`_
Tidal terms at 5PN and 6PN in the phase
  Eq.s (14-16) in `1410.8866 <https://arxiv.org/abs/1410.8866>`_

.. [*] These papers were not necessarily the first to present the corresponding expressions. We just refer to them for simplicity.
.. [*] We included quadrupole corrections at 3PN, but we neglected quadrupole and octupole corrections at 3.5PN.
